[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / ProofTypes

# Enumeration: ProofTypes

Types of ownership proofs supported by the system

## Remarks

Supported proof types:
- SelfDeclaration: User self-declares ownership without cryptographic proof
- EIP191: Ethereum personal signature following EIP-191 standard
- SIWE: Sign-In with Ethereum message signature (EIP-4361)
- EIP712: Ethereum typed data signature following EIP-712 standard
- BIP137: Bitcoin message signature following BIP-137
- BIP322: Bitcoin message signature following BIP-322
- TIP191: Tron message signing
- ED25519: Ed25519 signature (used in Solana)
- XPUB: Extended public key signature for HD wallets
- MicroTransfer: Proof via small blockchain transaction
- Screenshot: Image proof of ownership/access

## See

 - [SignatureProof](../interfaces/SignatureProof.md) For signature-based proofs
 - [DeclarationProof](../interfaces/DeclarationProof.md) For self-declaration proofs
 - [MicroTransferProof](../interfaces/MicroTransferProof.md) For transaction-based proofs
 - [ScreenshotProof](../interfaces/ScreenshotProof.md) For screenshot proofs

## Enumeration Members

### BIP137

> **BIP137**: `"bip-137"`

#### Defined in

[types.ts:1013](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1013)

***

### BIP137\_XPUB

> **BIP137\_XPUB**: `"xpub"`

#### Defined in

[types.ts:1015](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1015)

***

### BIP322

> **BIP322**: `"bip-322"`

#### Defined in

[types.ts:1014](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1014)

***

### Connect

> **Connect**: `"connect"`

#### Defined in

[types.ts:1020](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1020)

***

### ED25519

> **ED25519**: `"ed25519"`

#### Defined in

[types.ts:1017](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1017)

***

### EIP1271

> **EIP1271**: `"eip-1271"`

#### Defined in

[types.ts:1012](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1012)

***

### EIP191

> **EIP191**: `"eip-191"`

#### Defined in

[types.ts:1010](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1010)

***

### EIP712

> **EIP712**: `"eip-712"`

#### Defined in

[types.ts:1011](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1011)

***

### MicroTransfer

> **MicroTransfer**: `"microtransfer"`

#### Defined in

[types.ts:1018](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1018)

***

### Screenshot

> **Screenshot**: `"screenshot"`

#### Defined in

[types.ts:1019](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1019)

***

### SelfDeclaration

> **SelfDeclaration**: `"self-declaration"`

#### Defined in

[types.ts:1007](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1007)

***

### SIWE

> **SIWE**: `"siwe"`

#### Defined in

[types.ts:1008](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1008)

***

### SIWX

> **SIWX**: `"siwx"`

#### Defined in

[types.ts:1009](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1009)

***

### TIP191

> **TIP191**: `"tip-191"`

#### Defined in

[types.ts:1016](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/06342c6adf6f9cad152dcf6ecd0c80e7eb65778c/src/types.ts#L1016)
